#!/usr/bin/env python
"""handy.py is a collection of handy functions"""

from __future__ import division
import pygtk
pygtk.require("2.0")
import sys, gtk
import os
import threading
import const

# create a message box, and return which button was pressed     
def message_box(message="", title="", buttons=None, pixmap=None, modal= True):
    """Display message box and return result
    Please only use this function from processes that are not running gtk.main()
    title: title of the window
    message: the message to be displayed
    buttons: a tuple containing the text of the buttons, if not specified, will 
    default to ((True, gtk.STOCK_YES),)
    default: the number (starting at 0) of the default button
    modal=Is the message dialog modal"""
    # from http://www.rexx.com/~dkuhlman/python_201/python_201.html
    # with modifications
    
        
    class MessageBox(gtk.Dialog):
        def __init__(self, message="", buttons=(), pixmap=None,
                modal=True):
            gtk.Dialog.__init__(self)
            self.connect("destroy", self.quit)
            self.connect("delete_event", self.quit)
            if modal:
                self.set_modal(True)
            hbox = gtk.HBox(spacing=5)
            hbox.set_border_width(5)
            self.vbox.pack_start(hbox)
            hbox.show()
            if pixmap:
                self.realize()
                #pixmap = Pixmap(self, pixmap)
                im = gtk.Image()
                im.set_from_stock(pixmap, gtk.ICON_SIZE_DIALOG)
                hbox.pack_start(im, expand=False)
                im.show()
            label = gtk.Label(message)
            hbox.pack_start(label)
            label.show()
            for isStock, text in buttons:
                b = gtk.Button(text)
                b.set_flags(gtk.CAN_DEFAULT)
                b.set_label(text)
                if isStock:
                    b.set_use_stock(True)
                b.connect("clicked", self.click)
                self.action_area.pack_start(b)
                b.show()
            self.ret = None
        def quit(self, *args):
            self.hide()
            self.destroy()
            gtk.main_quit()
        def click(self, button):
            self.ret = button.get_label()
            self.quit()
    
    if buttons is None:
        buttons = ((True, gtk.STOCK_OK),)
    
    win = MessageBox(message, buttons, pixmap=pixmap, modal=modal)
    win.set_title(title)
    win.set_skip_taskbar_hint(False)
    win.show()
    gtk.gdk.threads_enter()
    gtk.main()
    gtk.gdk.threads_leave()
    return win.ret

def show_error(text, terminalText=None):
    """displays an error alert box using message_box and prints to sys.stderr
    For use in threads other than gtk.main"""

    require_main_thread()
    if terminalText is None:
        terminalText = text
    print >> sys.stderr, terminalText
    message_box(text, title="Error", pixmap=gtk.STOCK_DIALOG_ERROR, buttons=((True, gtk.STOCK_OK),))


def require_main_thread():
    """Raises a RequireThreadTypeException if the current thread is not named
    "MainThread" """
    if threading.currentThread().getName() not in ("MainThread", const.GTK_LOOP_THREAD_NAME):
        import ep_exceptions
        raise ep_exceptions.RequireThreadTypeException()

def require_non_main_thread():
    """Raises a RequireThreadTypeException if the current thread is named
    "MainThread" """
    if threading.currentThread().getName() == "MainThread":
        import ep_exceptions
        raise ep_exceptions.RequireThreadTypeException()

def determine_path ():
    """returns the path of this .py file (just the directory)
    Borrowed from wxglade.py"""
    try:
        root = __file__
    except Exception, ee:
        print >> sys.stderr, "I'm sorry, but something is wrong."
        print >> sys.stderr, "There is no __file__ variable. Please contact the author."
        sys.exit (1)
        raise(ee)
    if os.path.islink (root):
        root = os.path.realpath (root)
    return os.path.dirname (os.path.abspath (root))

def get_first_text(thexml):
    """Get text of XML node (ignores comments)"""
    import xml.dom
    for el in thexml.childNodes:
        if el.nodeType == xml.dom.Node.TEXT_NODE:
            return el.data
    import ep_exceptions
    ee = ep_exceptions.NoFirstTextError(thexml.tagName)
    raise ee

def bytes_in_str(bytes):
    """Returns the number of bytes in a human-readable string format"""
    if bytes > 1073741824:
        return str(round(bytes / 1073741824, 2)) + "GB"
    elif bytes > 1048576:
        return str(round(bytes / 1048576, 1)) + "MB"
    elif bytes > 1024:
        return str(round(bytes / 1024, 0)) + "KB"
    else:
        return str(bytes) + "B"
    

def ignore(*args):
    pass

def main():
    print "This file should not be run"
    print determine_path()

if __name__ == "__main__":
    main()
