#!/usr/bin/env python
# Copyright 2008-2009 David D Lowe
# released under the GPLv3

from pigment import PigmentType, Pigment
from pigment_more import FileBasedPigment, FileBasedPigmentType
import pigment
import os, sys
import subprocess
from shell import SubprocessShell
import gconf
import gtk
from glob import glob
if __name__ == "__main__" or 'pychecker' in sys.argv[0]:
    sys.path.append("..")
import ep_exceptions
import handy
import hashlib
from gettext import gettext as _


class GnomeSplashType(FileBasedPigmentType):
    humanName = {"en":"Gnome Splash"}
    humanPluralName = {"en":"Gnome Splashes"}
    codeName = "gnomeSplash"
    abbreviation = "spl"
    directoryName = "gnomeSplashes"
    canGeneratePreview = True
    
    attachmentTypeHelp = _("The theme file should be an image file, with the extension png , jpg or gif")
    
    def get_Pigment(self):
        return GnomeSplash
    
    publicBaseDir = "/usr/share/pixmaps/splash"
    personalBaseDir = "~/.local/share/pixmaps/splash"
        

class GnomeSplash(FileBasedPigment):
    
    
    def __init__(self):
        FileBasedPigment.__init__(self)
        self.type = GnomeSplashType()
    
    def add_attachment(self, attachment, tempPath=None):
        try:
            FileBasedPigment.add_attachment(self, attachment, tempPath)
        except ep_exceptions.AttachmentNotFoundException:
            # handle pigments saved in 0.2.2 and before
            if os.path.exists(os.path.join(self.type.publicBaseDir, self.codeName + "-" + attachment)):
                raise ep_exceptions.PigmentMoreOldFormat(self, attachment)
            else:
                raise
    
    def upgrade_from_old_format(self, attachment, shell):
        shell.do(["mv", os.path.join(self.type.publicBaseDir, self.codeName + "-" + attachment),
            os.path.join(self.type.publicBaseDir, attachment)])
    
    def activate(self, progressCallback=None, shell=None):
        if progressCallback is None:
            progressCallback = lambda(a1): False
        if progressCallback(0.0): return
        client = gconf.client_get_default()
        client.set_string("/apps/gnome-session/options/splash_image", \
            os.path.join(self.type.publicBaseDir, self.attFilename))
        client.set_bool("/apps/gnome-session/options/show_splash_screen", True)
        progressCallback(1.0)

    def is_activated(self):
        if self.is_meat_activated():
            client = gconf.engine_get_default()
            return self.attPath == client.get_string("/apps/gnome-session/options/splash_image")
        else:
            return False
    
    def is_attachment_correct(self, attachmentIndex=None):
        if FileBasedPigment.is_attachment_correct(self, attachmentIndex):
            if attachmentIndex is None:
                attachmentIndex = 0
            extension = self.attachments[attachmentIndex].split(".")[-1]
            if not extension.lower() in ("png", "jpg", "gif"):
                return False
            return True
        else: return False
    
    def is_meat_activated(self):
        """Returns whether the meat of this pigment or similar to it is activated"""
        client = gconf.client_get_default()
        if client.get_bool("/apps/gnome-session/options/show_splash_screen", True) is False:
            return False
        (md1, md2) = (hashlib.md5(), hashlib.md5())
        try:
            f1 = file(self.attPath, 'rb')
            f2 = file(client.get_string("/apps/gnome-session/options/splash_image"), 'rb')
        except:
            return False
        for mm, ff in ((md1, f1), (md2, f2)):
            ss = ff.read(8096)
            if not ss:
                break
            mm.update(ss)
        return m1 == m2
        
    def generate_preview(self):
        if not os.path.exists(self.attPath):
            return None
        pb = gtk.gdk.pixbuf_new_from_file_at_size(self.attPath,  100,  75)
        if pb is None:
            return None
        else:
            self.preview = pb
            return pb
    
    def does_activation_require_root(self):
        """Returns whether the activation requires root rights.
        If it does, the pigment object will need a pexpect bash shell as root
        to be passed to some of its methods"""
        return False
    
    def get_display_data(self, index=0):
        """Returns the object of index to be added to a gtk.ListStore, this
        could be a string, a gtk.gdk.Pixbuf or a custom widget, it should
        be rendered using type.create_cell_renderer"""
        return

def main():
    wp = GnomeSplash()
    print wp.information_xml().toxml()

if __name__ == "__main__":
    main()
